@@ -26,7 +26,7 @@
 
 #include <config-kalzium.h>
 
-#define APP_VERSION "2.1.00"
+#define APP_VERSION "2.3.80"
 
 static const char description[] =
     I18N_NOOP("A periodic table of the elements");
@@ -51,6 +51,7 @@ int main(int argc, char **argv)
     about.addCredit( ki18n("Pino Toscano"), ki18n("Large code contributions; resident guru helping the other developers"));
     about.addCredit( ki18n("Benoit Jacob"), ki18n( "Base work on the molecular viewer, mentored Marcus during his SoC" ));
     about.addCredit( ki18n("Marcus Hanwell"), ki18n( "SoC on the molecular viewer and libavogadro porting/integration" ));
+    about.addCredit( ki18n("Kashyap R Puranik"), ki18n("SoC on the calculator widget and a few smaller improvements" ));    
     about.addCredit( ki18n("Thomas Nagy"), ki18n("EqChem, the equation solver" ));
     about.addCredit( ki18n("Inge Wallin"), ki18n( "Code cleaning, parser for the molecule weight calculator, and a lot of smaller improvements" ));
     about.addCredit( ki18n("Anne-Marie Mahfouf"), ki18n( "A lot of small things and the documentation" ));
@@ -64,11 +65,20 @@ int main(int argc, char **argv)
     about.addCredit( ki18n("Marco Martin"), ki18n("Some icons and inspiration for others" ));
     about.addCredit( ki18n("Daniel Haas"), ki18n( "The design of the information dialog" ));
     about.addCredit( ki18n("Brian Beck"), ki18n( "The orbits icon" ));
+
+    about.addCredit(ki18n("Paulo Cattai"),ki18n("New interface design and usability improvements"));
+    about.addCredit(ki18n("Danilo Balzaque"),ki18n("New interface design and usability improvements"));
+    about.addCredit(ki18n("Roberto Cunha"),ki18n("New interface design and usability improvements"));
+    about.addCredit(ki18n("Tadeu Araujo"),ki18n("New interface design and usability improvements"));
+    about.addCredit(ki18n("Tiago Porangaba"),ki18n("New interface design and usability improvements"));
+
     KCmdLineArgs::init(argc, argv, &about);
 
     KCmdLineOptions options;
     KCmdLineArgs::addCmdLineOptions( options );
     KApplication app;
+    KGlobal::locale()->insertCatalog("kalzium_qt");
+
     Kalzium *mainWin = 0;
 
     if (app.isSessionRestored())
