@@ -14,7 +14,7 @@
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
+ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301
  USA
 **/
 
@@ -25,55 +25,46 @@
 #include "kig_document.h"
 #include "kig_commands.h"
 #include "../misc/coordinate_system.h"
+#include "../misc/kiginputdialog.h"
 #include "../misc/kigpainter.h"
-#include "zoomarea.h"
 #include "../modes/mode.h"
 #include "../modes/dragrectmode.h"
 
-#include <qdialog.h>
-#include <qwhatsthis.h>
+#include <qapplication.h>
+#include <qevent.h>
 #include <qlayout.h>
 #include <qscrollbar.h>
 
 #include <kdebug.h>
-#include <kcursor.h>
 #include <klocale.h>
-#include <kapplication.h>
-#include <kstdaction.h>
-#include <kaction.h>
-#include <kiconloader.h>
 
 #include <cmath>
 #include <algorithm>
 
-kdbgstream& operator<< ( kdbgstream& s, const QPoint& t )
-{
-  s << "x: " << t.x() << " y: " << t.y();
-  return s;
-}
-
 KigWidget::KigWidget( KigPart* part,
                       KigView* view,
                       QWidget* parent,
-                      const char* name,
                       bool fullscreen )
-  : QWidget( parent, name,
-             fullscreen ? WStyle_Customize | WStyle_NoBorder : 0 ),
+  : QWidget( parent,
+             fullscreen ? Qt::FramelessWindowHint : (Qt::WFlags)0 ),
     mpart( part ),
     mview( view ),
     stillPix(size()),
     curPix(size()),
     msi( Rect(), rect() ),
-    misfullscreen( fullscreen )
+    misfullscreen( fullscreen ),
+    mispainting( false ),
+    malreadyresized( false )
 {
+  setAttribute( Qt::WA_PaintOnScreen, true );
   part->addWidget(this);
 
-  setFocusPolicy(QWidget::ClickFocus);
-  setBackgroundMode( Qt::NoBackground );
+  setFocusPolicy(Qt::ClickFocus);
+  setAttribute( Qt::WA_NoBackground, true );
   setMouseTracking(true);
 
-  curPix.resize( size() );
-  stillPix.resize( size() );
+  curPix = QPixmap( size() );
+  stillPix = QPixmap( size() );
 }
 
 KigWidget::~KigWidget()
@@ -81,9 +72,12 @@ KigWidget::~KigWidget()
   mpart->delWidget( this );
 }
 
-void KigWidget::paintEvent(QPaintEvent*)
+void KigWidget::paintEvent(QPaintEvent* e)
 {
-  updateEntireWidget();
+  mispainting = true;
+  std::vector<QRect> overlay;
+  overlay.push_back( e->rect() );
+  updateWidget( overlay );
 }
 
 void KigWidget::mousePressEvent (QMouseEvent* e)
@@ -98,44 +92,57 @@ void KigWidget::mousePressEvent (QMouseEvent* e)
 
 void KigWidget::mouseMoveEvent (QMouseEvent* e)
 {
-  if( e->state() & Qt::LeftButton )
+  if( ( e->buttons() & Qt::LeftButton ) == Qt::LeftButton )
     return mpart->mode()->leftMouseMoved( e, this );
-  if ( e->state() & Qt::MidButton )
+  if ( ( e->buttons() & Qt::MidButton ) == Qt::MidButton )
     return mpart->mode()->midMouseMoved( e, this );
-  if ( e->state() & Qt::RightButton )
+  if ( ( e->buttons() & Qt::RightButton ) == Qt::RightButton )
     return mpart->mode()->rightMouseMoved( e, this );
   return mpart->mode()->mouseMoved( e, this );
 }
 
 void KigWidget::mouseReleaseEvent (QMouseEvent* e)
 {
-  if( e->state() & Qt::LeftButton )
+  if( e->button() & Qt::LeftButton )
     return mpart->mode()->leftReleased( e, this );
-  if ( e->state() & Qt::MidButton )
+  if ( e->button() & Qt::MidButton )
     return mpart->mode()->midReleased( e, this );
-  if ( e->state() & Qt::RightButton )
+  if ( e->button() & Qt::RightButton )
     return mpart->mode()->rightReleased( e, this );
 }
 
 void KigWidget::updateWidget( const std::vector<QRect>& overlay )
 {
-#undef SHOW_OVERLAY_RECTS
-#ifdef SHOW_OVERLAY_RECTS
-  QPainter debug (this, this);
-  debug.setPen(Qt::yellow);
-#endif // SHOW_OVERLAY_RECTS
-  // we undo our old changes...
-  for ( std::vector<QRect>::const_iterator i = oldOverlay.begin(); i != oldOverlay.end(); ++i )
-    bitBlt( this, i->topLeft(), &curPix, *i );
-  // we add our new changes...
-  for ( std::vector<QRect>::const_iterator i = overlay.begin(); i != overlay.end(); ++i )
+  if ( !mispainting )
   {
-    bitBlt( this, i->topLeft(), &curPix, *i );
-#ifdef SHOW_OVERLAY_RECTS
-    debug.drawRect(*i);
-#endif
-  };
+    QRect r;
+    int rectinited = false;
+    for ( std::vector<QRect>::const_iterator i = oldOverlay.begin(); i != oldOverlay.end(); ++i )
+      if ( rectinited )
+        r |= *i;
+      else
+      {
+        r = *i;
+        rectinited = true;
+      }
+    for ( std::vector<QRect>::const_iterator i = overlay.begin(); i != overlay.end(); ++i )
+      if ( rectinited )
+        r |= *i;
+      else
+      {
+        r = *i;
+        rectinited = true;
+      }
+    repaint( r );
+    return;
+  }
+
   oldOverlay = overlay;
+
+  QPainter p( this );
+  p.drawPixmap( overlay.front().topLeft(), curPix, overlay.front() );
+  p.end();
+  mispainting = false;
 }
 
 void KigWidget::updateEntireWidget()
@@ -151,8 +158,8 @@ void KigWidget::resizeEvent( QResizeEvent* e )
   QSize nsize = e->size();
   Rect orect = msi.shownRect();
 
-  curPix.resize( nsize );
-  stillPix.resize( nsize );
+  curPix = QPixmap( nsize );
+  stillPix = QPixmap( nsize );
   msi.setViewRect( rect() );
 
   Rect nrect( 0., 0.,
@@ -166,7 +173,11 @@ void KigWidget::resizeEvent( QResizeEvent* e )
   // resizeEvents we get on startup, and the ones generated by the
   // user.  The first require recentering the screen, the latter
   // don't..
-  if ( nsize.width() / osize.width() > 4 ) recenterScreen();
+  if ( !malreadyresized )
+  {
+    recenterScreen();
+    malreadyresized = true;
+  }
 
   mpart->redrawScreen( this );
   updateScrollBars();
@@ -175,10 +186,12 @@ void KigWidget::resizeEvent( QResizeEvent* e )
 void KigWidget::updateCurPix( const std::vector<QRect>& ol )
 {
   // we make curPix look like stillPix again...
+  QPainter p( &curPix );
   for ( std::vector<QRect>::const_iterator i = oldOverlay.begin(); i != oldOverlay.end(); ++i )
-    bitBlt( &curPix, i->topLeft(), &stillPix, *i );
+    p.drawPixmap( i->topLeft(), stillPix, *i );
   for ( std::vector<QRect>::const_iterator i = ol.begin(); i != ol.end(); ++i )
-    bitBlt( &curPix, i->topLeft(), &stillPix, *i );
+    p.drawPixmap( i->topLeft(), stillPix, *i );
+  p.end();
 
   // we add ol to oldOverlay, so that part of the widget will be
   // updated too in updateWidget...
@@ -205,7 +218,7 @@ void KigWidget::slotZoomIn()
     new KigCommand( *mpart,
                     i18n( "Zoom In" ) );
   cd->addTask( new KigViewShownRectChangeTask( *this, nr ) );
-  mpart->history()->addCommand( cd );
+  mpart->history()->push( cd );
 }
 
 void KigWidget::slotZoomOut()
@@ -225,7 +238,7 @@ void KigWidget::slotZoomOut()
     new KigCommand( *mpart,
                     i18n( "Zoom Out" ) );
   cd->addTask( new KigViewShownRectChangeTask( *this, nr ) );
-  mpart->history()->addCommand( cd );
+  mpart->history()->push( cd );
 }
 
 void KigWidget::clearStillPix()
@@ -235,10 +248,12 @@ void KigWidget::clearStillPix()
   oldOverlay.push_back ( QRect( QPoint(0,0), size() ) );
 }
 
-void KigWidget::redrawScreen( const std::vector<ObjectHolder*>& selection, bool dos )
+void KigWidget::redrawScreen( const std::vector<ObjectHolder*>& _selection, bool dos )
 {
   std::vector<ObjectHolder*> nonselection;
+  std::vector<ObjectHolder*> selection = _selection;
   std::set<ObjectHolder*> objs = mpart->document().objectsSet();
+  std::sort( selection.begin(), selection.end() );
   std::set_difference( objs.begin(), objs.end(), selection.begin(), selection.end(),
                        std::back_inserter( nonselection ) );
 
@@ -286,29 +301,33 @@ void KigWidget::updateScrollBars()
 
 KigView::KigView( KigPart* part,
                   bool fullscreen,
-                  QWidget* parent,
-                  const char* name )
-  : QWidget( parent, name ),
+                  QWidget* parent )
+  : QWidget( parent ),
     mlayout( 0 ), mrightscroll( 0 ), mbottomscroll( 0 ),
     mupdatingscrollbars( false ),
     mrealwidget( 0 ), mpart( part )
 {
   connect( part, SIGNAL( recenterScreen() ), this, SLOT( slotInternalRecenterScreen() ) );
 
-  mlayout = new QGridLayout( this, 2, 2 );
-  mrightscroll = new QScrollBar( Vertical, this, "Right Scrollbar" );
+  mlayout = new QGridLayout( this );
+  mlayout->setMargin( 2 );
+  mlayout->setSpacing( 2 );
+  mrightscroll = new QScrollBar( Qt::Vertical, this );
+  mrightscroll->setObjectName( "Right Scrollbar" );
   // TODO: make this configurable...
   mrightscroll->setTracking( true );
   connect( mrightscroll, SIGNAL( valueChanged( int ) ),
            this, SLOT( slotRightScrollValueChanged( int ) ) );
   connect( mrightscroll, SIGNAL( sliderReleased() ),
            this, SLOT( updateScrollBars() ) );
-  mbottomscroll = new QScrollBar( Horizontal, this, "Bottom Scrollbar" );
+  mbottomscroll = new QScrollBar( Qt::Horizontal, this );
+  mbottomscroll->setObjectName( "Bottom Scrollbar" );
   connect( mbottomscroll, SIGNAL( valueChanged( int ) ),
            this, SLOT( slotBottomScrollValueChanged( int ) ) );
   connect( mbottomscroll, SIGNAL( sliderReleased() ),
            this, SLOT( updateScrollBars() ) );
-  mrealwidget = new KigWidget( part, this, this, "Kig Widget", fullscreen );
+  mrealwidget = new KigWidget( part, this, this, fullscreen );
+  mrealwidget->setObjectName( "Kig Widget" );
   mlayout->addWidget( mbottomscroll, 1, 0 );
   mlayout->addWidget( mrealwidget, 0, 0 );
   mlayout->addWidget( mrightscroll, 0, 1 );
@@ -342,7 +361,7 @@ void KigView::updateScrollBars()
   // we need ints, not doubles, so since "pixelwidth == widgetcoord /
   // internalcoord", we use "widgetcoord/pixelwidth", which would then
   // equal "internalcoord", which has to be an int ( by definition.. )
-  // i know, i'm a freak to think about these sorts of things... ;)
+  // i know, I'm a freak to think about these sorts of things... ;)
   double pw = mrealwidget->screenInfo().pixelWidth();
 
   // what the scrollbars reflect is the bottom resp. the left side of
@@ -354,9 +373,9 @@ void KigView::updateScrollBars()
   int rightmin = static_cast<int>( er.bottom() / pw );
   int rightmax = static_cast<int>( ( er.top() - sr.height() ) / pw );
 
-  mrightscroll->setMinValue( rightmin );
-  mrightscroll->setMaxValue( rightmax );
-  mrightscroll->setLineStep( (int)( sr.height() / pw / 10 ) );
+  mrightscroll->setMinimum( rightmin );
+  mrightscroll->setMaximum( rightmax );
+  mrightscroll->setSingleStep( (int)( sr.height() / pw / 10 ) );
   mrightscroll->setPageStep( (int)( sr.height() / pw / 1.2 ) );
 
   // note that since Qt has a coordinate system with the lowest y
@@ -366,9 +385,9 @@ void KigView::updateScrollBars()
   // slotRightScrollValueChanged()...
   mrightscroll->setValue( (int) ( rightmin + ( rightmax - ( sr.bottom() / pw ) ) ) );
 
-  mbottomscroll->setMinValue( (int)( er.left() / pw ) );
-  mbottomscroll->setMaxValue( (int)( ( er.right() - sr.width() ) / pw ) );
-  mbottomscroll->setLineStep( (int)( sr.width() / pw / 10 ) );
+  mbottomscroll->setMinimum( (int)( er.left() / pw ) );
+  mbottomscroll->setMaximum( (int)( ( er.right() - sr.width() ) / pw ) );
+  mbottomscroll->setSingleStep( (int)( sr.width() / pw / 10 ) );
   mbottomscroll->setPageStep( (int)( sr.width() / pw / 1.2 ) );
   mbottomscroll->setValue( (int)( sr.left() / pw ) );
 
@@ -386,7 +405,7 @@ void KigView::slotRightScrollValueChanged( int v )
   {
     // we invert the inversion that was done in updateScrollBars() (
     // check the documentation there..; )
-    v = mrightscroll->minValue() + ( mrightscroll->maxValue() - v );
+    v = mrightscroll->minimum() + ( mrightscroll->maximum() - v );
     double pw = mrealwidget->screenInfo().pixelWidth();
     double nb = double( v ) * pw;
     mrealwidget->scrollSetBottom( nb );
@@ -461,20 +480,20 @@ void KigView::scrollHorizontal( int delta )
 {
   if ( delta >= 0 )
     for ( int i = 0; i < delta; i += 120 )
-      mbottomscroll->subtractLine();
+      mbottomscroll->triggerAction( QScrollBar::SliderSingleStepSub );
   else
     for ( int i = 0; i >= delta; i -= 120 )
-      mbottomscroll->addLine();
+      mbottomscroll->triggerAction( QScrollBar::SliderSingleStepAdd );
 }
 
 void KigView::scrollVertical( int delta )
 {
   if ( delta >= 0 )
     for ( int i = 0; i < delta; i += 120 )
-      mrightscroll->subtractLine();
+      mrightscroll->triggerAction( QScrollBar::SliderSingleStepSub );
   else
     for ( int i = 0; i >= delta; i -= 120 )
-      mrightscroll->addLine();
+      mrightscroll->triggerAction( QScrollBar::SliderSingleStepAdd );
 }
 
 bool KigWidget::isFullScreen() const
@@ -500,16 +519,16 @@ void KigWidget::slotRecenterScreen()
                     i18n( "Recenter View" ) );
 
   cd->addTask( new KigViewShownRectChangeTask( *this, nr ) );
-  mpart->history()->addCommand( cd );
+  mpart->history()->push( cd );
 }
 
 void KigView::toggleFullScreen()
 {
   mrealwidget->setFullScreen( ! mrealwidget->isFullScreen() );
   if ( mrealwidget->isFullScreen() )
-    topLevelWidget()->showFullScreen();
+    topLevelWidget()->setWindowState( topLevelWidget()->windowState() | Qt::WindowFullScreen ); // set
   else
-    topLevelWidget()->showNormal();
+    topLevelWidget()->setWindowState( topLevelWidget()->windowState() & ~Qt::WindowFullScreen ); // reset
 }
 
 void KigWidget::setFullScreen( bool f )
@@ -530,7 +549,7 @@ void KigWidget::zoomRect()
                       i18n( "Change Shown Part of Screen" ) );
 
     cd->addTask( new KigViewShownRectChangeTask( *this, nr ) );
-    mpart->history()->addCommand( cd );
+    mpart->history()->push( cd );
   };
 
   mpart->redrawScreen( this );
@@ -560,25 +579,26 @@ void KigView::slotInternalRecenterScreen()
 void KigWidget::zoomArea()
 {
 //  mpart->emitStatusBarText( i18n( "Select the area that should be shown." ) );
-  ZoomArea* za = new ZoomArea( this, mpart->document() );
   Rect oldrect = showingRect();
-  Coordinate tc = oldrect.topLeft();
-  za->setCoord0( tc );
-  tc = oldrect.bottomRight();
-  za->setCoord1( tc );
-  if ( za->exec() )
+  Coordinate tl = oldrect.topLeft();
+  Coordinate br = oldrect.bottomRight();
+  bool ok = true;
+  KigInputDialog::getTwoCoordinates( i18n( "Select Zoom Area" ),
+        i18n( "Select the zoom area by entering the coordinates<br />"
+              "of the upper left corner and the lower right corner." ) +
+        QString::fromLatin1( "<br />" ) +
+        mpart->document().coordinateSystem().coordinateFormatNoticeMarkup(),
+        this, &ok, mpart->document(), &tl, &br );
+  if ( ok )
   {
-    Coordinate c1 = za->coord0();
-    Coordinate c2 = za->coord1();
-    Coordinate nc1( c2.y, c1.x );
-    Coordinate nc2( c1.y, c2.x );
+    Coordinate nc1( tl.x, br.y );
+    Coordinate nc2( br.x, tl.y );
     Rect nr( nc1, nc2 );
     KigCommand* cd = new KigCommand( *mpart, i18n( "Change Shown Part of Screen" ) );
 
     cd->addTask( new KigViewShownRectChangeTask( *this, nr ) );
-    mpart->history()->addCommand( cd );
+    mpart->history()->push( cd );
   }
-  delete za;
 
   mpart->redrawScreen( this );
   updateScrollBars();
