@@ -1,5 +1,5 @@
 /* This file is part of KWordQuiz
-  Copyright (C) 2003 Peter Hedlund <peter@peterandlinda.com>
+  Copyright (C) 2003 Peter Hedlund <peter.hedlund@kdemail.net>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
@@ -12,25 +12,23 @@
 
   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-  Boston, MA 02111-1307, USA.
+  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+  Boston, MA 02110-1301, USA.
 */
 
 #ifndef PREFEDITOR_H
 #define PREFEDITOR_H
 
-#include "prefeditorbase.h"
+#include "ui_prefeditorbase.h"
 
 /**
 @author Peter Hedlund
 */
-class PrefEditor : public PrefEditorBase
+class PrefEditor : public QWidget, public Ui::PrefEditorBase
 {
 Q_OBJECT
 public:
-
-  PrefEditor(QWidget *parent, const char *name=0, WFlags f=0);
-  ~PrefEditor();
+  PrefEditor(QWidget *parent);
 
 };
 
