@@ -5,7 +5,7 @@
 // find a copy of this license in LICENSE.txt in the top directory of
 // the source code.
 //
-// Copyright 2008      Inge Wallin  <ingwa@kde.org>"
+// Copyright 2008      Inge Wallin  <ingwa@kde.org>
 //
 
 //
@@ -32,16 +32,16 @@
 
 #include "global.h"
 
-class QAbstractItemModel;
 
 namespace Marble
 {
 
 class MarbleModel;
 class MarbleGeoDataModel;
-class MarbleDataFacadePrivate;
-class GeoDataDocument;
+class MarbleGeometryModel;
+class MarblePlacemarkModel;
 class FileViewModel;
+class MarbleDataFacadePrivate;
 class Planet;
 
 /**
@@ -77,8 +77,9 @@ class MARBLE_EXPORT MarbleDataFacade
 
     MarbleGeoDataModel* geoDataModel();
     
-    QAbstractItemModel* renderModel();
-    
+    MarbleGeometryModel* geometryModel();
+
+    MarblePlacemarkModel* placemarkModel();
     FileViewModel* fileViewModel() const;
  private:
     MarbleDataFacadePrivate  * const d;
