@@ -5,9 +5,10 @@
 // find a copy of this license in LICENSE.txt in the top directory of
 // the source code.
 //
-// Copyright 2006-2009 Torsten Rahn <tackat@kde.org>"
-// Copyright 2007      Inge Wallin  <ingwa@kde.org>"
+// Copyright 2006-2009 Torsten Rahn <tackat@kde.org>
+// Copyright 2007      Inge Wallin  <ingwa@kde.org>
 // Copyright 2008      Carlos Licea <carlos.licea@kdemail.net>
+// Copyright 2009      Jens-Michael Hoffmann <jensmh@gmx.de>
 //
 
 
@@ -20,7 +21,6 @@
 
 // Qt
 #include <QtCore/QCoreApplication>
-#include <QtCore/QDebug>
 #include <QtCore/QAbstractItemModel>
 #include <QtCore/QTime>
 #include <QtGui/QItemSelectionModel>
@@ -32,6 +32,7 @@
 #endif
 
 // Marble
+#include "MarbleDebug.h"
 #include "AbstractProjection.h"
 #include "AbstractScanlineTextureMapper.h"
 #include "GeoPainter.h"
@@ -42,7 +43,6 @@
 #include "GeoSceneDocument.h"
 #include "GeoSceneHead.h"
 #include "GeoSceneZoom.h"
-#include "GpxFileViewItem.h"
 #include "HttpDownloadManager.h"
 #include "MarbleDirs.h"
 #include "MarbleLocale.h"
@@ -112,6 +112,9 @@ void MarbleMapPrivate::construct()
     m_parent->connect( m_model->sunLocator(), SIGNAL( centerSun() ),
                        m_parent,              SLOT( centerSun() ) );
 
+    m_parent->connect( m_model,               SIGNAL( repaintNeeded( QRegion ) ),
+                       m_parent,              SIGNAL( repaintNeeded( QRegion ) ) );
+
     // A new instance of FileStorageWatcher.
     // The thread will be started at setting persistent tile cache size.
     m_storageWatcher = new FileStorageWatcher( MarbleDirs::localPath(), m_parent );
@@ -132,15 +135,22 @@ void MarbleMapPrivate::doResize()
 {
     QSize size(m_parent->width(), m_parent->height());
     m_viewParams.viewport()->setSize( size );
+
+    // If the globe covers fully the screen then we can use the faster
+    // RGB32 as there are no translucent areas involved.
+    QImage::Format imageFormat = ( m_parent->mapCoversViewport() )
+                                 ? QImage::Format_RGB32
+                                 : QImage::Format_ARGB32_Premultiplied;
+
     // Recreate the canvas image with the new size.
     m_viewParams.setCanvasImage( new QImage( m_parent->width(), m_parent->height(),
-                                             QImage::Format_RGB32 ));
+                                             imageFormat ));
 
     if ( m_viewParams.showAtmosphere() ) {
         m_dirtyAtmosphere=true;
     }
 
-    // Recreate the 
+    // Recreate the coastline detection offscreen image
     m_viewParams.setCoastImage( new QImage( m_parent->width(), m_parent->height(),
                                             QImage::Format_RGB32 ));
 
@@ -261,7 +271,7 @@ void MarbleMapPrivate::drawFog( QPainter &painter )
 void MarbleMapPrivate::paintGround( GeoPainter &painter, QRect &dirtyRect )
 {
     if ( !m_viewParams.mapTheme() ) {
-        qDebug() << "No theme yet!";
+        mDebug() << "No theme yet!";
         paintMarbleSplash( painter, dirtyRect );
         return;
     }
@@ -285,7 +295,7 @@ void MarbleMapPrivate::paintGround( GeoPainter &painter, QRect &dirtyRect )
     //        PrintQuality. Either cache on a pixmap - or maybe
     //        better: Add to GlobeScanlineTextureMapper.
 
-    if ( m_viewParams.mapQuality() == Marble::Print )
+    if ( m_viewParams.mapQuality() == Marble::PrintQuality )
         drawFog( painter );
 }
 
@@ -302,8 +312,8 @@ void MarbleMapPrivate::paintOverlay( GeoPainter &painter, QRect &dirtyRect )
 
     bool antialiased = false;
 
-    if (   m_viewParams.mapQuality() == Marble::High
-        || m_viewParams.mapQuality() == Marble::Print ) {
+    if (   m_viewParams.mapQuality() == Marble::HighQuality
+        || m_viewParams.mapQuality() == Marble::PrintQuality ) {
             antialiased = true;
     }
 
@@ -351,6 +361,7 @@ MarbleMap::MarbleMap()
     d->m_modelIsOwned = true;
 
     d->construct();
+    d->m_model->setupVectorComposer();
     qDebug("Model: Time elapsed: %d ms", t.elapsed());
 }
 
@@ -365,6 +376,7 @@ MarbleMap::MarbleMap(MarbleModel *model)
     d->m_modelIsOwned = false;
 
     d->construct();
+    d->m_model->setupVectorComposer();
 }
 
 MarbleMap::~MarbleMap()
@@ -508,7 +520,7 @@ void MarbleMap::setDistance( qreal distance )
     qreal minDistance = 0.001;
 
     if ( distance <= minDistance ) {
-        qDebug() << "Invalid distance: 0 m";
+        mDebug() << "Invalid distance: 0 m";
         distance = minDistance;
     }
     
@@ -583,7 +595,8 @@ QPixmap MarbleMap::mapScreenShot()
     QPixmap screenshotPixmap( size() );
     screenshotPixmap.fill( Qt::transparent );
 
-    GeoPainter painter( &screenshotPixmap, viewParams()->viewport(), Marble::Print );
+    GeoPainter painter( &screenshotPixmap, viewParams()->viewport(),
+                        Marble::PrintQuality );
     painter.begin( &screenshotPixmap );
     QRect dirtyRect( QPoint(), size() );
     paint( painter, dirtyRect );
@@ -592,6 +605,11 @@ QPixmap MarbleMap::mapScreenShot()
     return screenshotPixmap;
 }
 
+void MarbleMap::reload() const
+{
+    d->m_model->reloadMap();
+}
+
 bool MarbleMap::propertyValue( const QString& name ) const
 {
     bool value;
@@ -635,7 +653,8 @@ bool MarbleMap::showCrosshairs() const
 
     QList<RenderPlugin *> pluginList = renderPlugins();
     QList<RenderPlugin *>::const_iterator i = pluginList.constBegin();
-    for (; i != pluginList.constEnd(); ++i) {
+    QList<RenderPlugin *>::const_iterator const end = pluginList.constEnd();
+    for (; i != end; ++i ) {
         if ( (*i)->nameId() == "crosshairs" ) {
             visible = (*i)->visible();
         }
@@ -974,7 +993,7 @@ void MarbleMap::setMapThemeId( const QString& mapThemeId )
 
 void MarbleMap::setPropertyValue( const QString& name, bool value )
 {
-    qDebug() << "In MarbleMap the property " << name << "was set to " << value;
+    mDebug() << "In MarbleMap the property " << name << "was set to " << value;
     d->m_viewParams.setPropertyValue( name, value );
 }
 
@@ -1009,7 +1028,8 @@ void MarbleMap::setShowCrosshairs( bool visible )
 {
     QList<RenderPlugin *> pluginList = renderPlugins();
     QList<RenderPlugin *>::const_iterator i = pluginList.constBegin();
-    for (; i != pluginList.constEnd(); ++i) {
+    QList<RenderPlugin *>::const_iterator const end = pluginList.constEnd();
+    for (; i != end; ++i ) {
         if ( (*i)->nameId() == "crosshairs" ) {
             (*i)->setVisible( visible );
         }
@@ -1023,7 +1043,7 @@ void MarbleMap::setShowClouds( bool visible )
     d->m_model->layerDecorator()->setShowClouds( visible );
 
     if ( previousVisible != visible ) {
-        qDebug() << "Changing cloud layer";
+        mDebug() << "Changing cloud layer";
         d->m_model->update();
     }
 }
@@ -1138,12 +1158,7 @@ void MarbleMap::updateGps()
 
 void MarbleMap::openGpxFile(QString &filename)
 {
-#ifndef KML_GSOC
-    d->m_model->gpsLayer()->loadGpx( filename );
-#else
-    GpxFileViewItem* item = new GpxFileViewItem( new GpxFile( filename ) );
-    d->m_model->fileViewModel()->append( item );
-#endif
+    d->m_model->openGpxFile( filename );
 }
 
 GpxFileModel *MarbleMap::gpxFileModel()
@@ -1185,7 +1200,7 @@ void MarbleMap::clearVolatileTileCache()
 
 void MarbleMap::setVolatileTileCacheLimit( quint64 kilobytes )
 {
-    qDebug() << "kiloBytes" << kilobytes;
+    mDebug() << "kiloBytes" << kilobytes;
     d->m_volatileTileCacheLimit = kilobytes;
     d->m_model->setVolatileTileCacheLimit( kilobytes );
 }
@@ -1220,7 +1235,7 @@ QString MarbleMap::distanceString() const
     const Marble::DistanceUnit distanceUnit = MarbleGlobal::getInstance()->locale()->distanceUnit();
 
     // FIXME: why is "km" translated and "mi" not?
-    if ( distanceUnit == Marble::Metric ) {
+    if ( distanceUnit == Marble::Meter ) {
         distanceUnitString = tr("km");
     }
     else {
@@ -1272,10 +1287,10 @@ void MarbleMap::updateSun()
     // Update the sun shading.
     //SunLocator  *sunLocator = d->m_model->sunLocator();
 
-    qDebug() << "MarbleMap: Updating the sun shading map...";
+    mDebug() << "MarbleMap: Updating the sun shading map...";
     d->m_model->update();
     setNeedsUpdate();
-    //qDebug() << "Finished updating the sun shading map";
+    //mDebug() << "Finished updating the sun shading map";
 }
 
 void MarbleMap::centerSun()
@@ -1287,7 +1302,7 @@ void MarbleMap::centerSun()
         qreal  lat = sunLocator->getLat();
         centerOn( lon, lat );
 
-        qDebug() << "Centering on Sun at " << lat << lon;
+        mDebug() << "Centering on Sun at " << lat << lon;
     }
 }
 
