@@ -5,8 +5,8 @@
 // find a copy of this license in LICENSE.txt in the top directory of
 // the source code.
 //
-// Copyright 2006-2007 Torsten Rahn <tackat@kde.org>"
-// Copyright 2007      Inge Wallin  <ingwa@kde.org>"
+// Copyright 2006-2007 Torsten Rahn <tackat@kde.org>
+// Copyright 2007      Inge Wallin  <ingwa@kde.org>
 //
 
 
@@ -15,8 +15,10 @@
 
 
 #include <QtCore/QVector>
-#include <QtGui/QPolygon>
+#include <QtGui/QPolygonF>
 
+namespace Marble
+{
 
 class ScreenPolygon : public QPolygonF 
 {
@@ -36,4 +38,6 @@ class ScreenPolygon : public QPolygonF
     bool  m_closed;
 };
 
+}
+
 #endif // SCREENPOLYGON_H
