@@ -24,12 +24,18 @@
 
 #include "GeoTagHandler.h"
 
-class DgmlInstallMapTagHandler : public GeoTagHandler {
-public:
-    DgmlInstallMapTagHandler();
-    virtual ~DgmlInstallMapTagHandler();
+namespace Marble
+{
+namespace dgml
+{
 
+class DgmlInstallMapTagHandler : public GeoTagHandler
+{
+public:
     virtual GeoNode* parse(GeoParser&) const;
 };
 
+}
+}
+
 #endif // DgmlInstallMapTagHandler_h
